==> piwigo-2.5.1.zip: piwigo/language/gl_ES/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['You do not have access rights to run upgrade'] = 'Non tes dereitos de acceso para actualizar';
$lang['Upgrade informations'] = 'Actualizar información';
$lang['User permissions and group permissions have been erased'] = 'Borráronse os permisos dos usuarios e grupos';
$lang['total SQL time'] = 'tempo total de SQL';
$lang['total upgrade time'] = 'tempo total da actualización';
$lang['Upgrade'] = 'Actualizar';
$lang['Upgrade from version %s to %s'] = 'Actualizar da versión %s para a versión %s';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Esta páxina proponche pór ó día a base de datos da túa antiga versión de Piwigo cara a nova versión. O asistente de actualización detectou a túa <strong>versión como a %s</strong> (ou equivalente).';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Executa unha comprobación de mantemento en [Administración>Ferramentas>Mantemento] se atopas algún problema.';
$lang['SQL queries'] = 'Consultas SQL';
$lang['Statistics'] = 'Estatísticas';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Da anterior configuración só se salvaron os prefixos das miniaturas e o correo do administrador web';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Só o administrador pode efectuar actualizacións: inicia sesión no formulario de abaixo.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'En <i>%s</i>, antes de <b>?></b>, insira:';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Por precaución, os seguintes engadidos foron desactivados. Tes que comprobar se teñen actualización antes de reactivalos:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Por precaución, os seguintes temas foron desactivados. Tes que comprobar se teñen actualización antes de reactivalos:';
$lang['All sub-albums of private albums become private'] = 'Tódolos sub-álbums de álbums privados tórnanse privados';
?>

==> piwigo-16.0.0.zip: piwigo/language/gl_ES/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['You do not have access rights to run upgrade'] = 'Non tes dereitos de acceso para actualizar';
$lang['Upgrade informations'] = 'Actualizar información';
$lang['User permissions and group permissions have been erased'] = 'Borráronse os permisos dos usuarios e grupos';
$lang['total SQL time'] = 'tempo total de SQL';
$lang['total upgrade time'] = 'tempo total da actualización';
$lang['Upgrade'] = 'Actualizar';
$lang['Upgrade from version %s to %s'] = 'Actualizar da versión %s para a versión %s';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Esta páxina proponche pór ó día a base de datos da túa antiga versión de Piwigo cara a nova versión. O asistente de actualización detectou a túa <strong>versión como a %s</strong> (ou equivalente).';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Executa unha comprobación de mantemento en [Administración>Ferramentas>Mantemento] se atopas algún problema.';
$lang['SQL queries'] = 'Consultas SQL';
$lang['Statistics'] = 'Estatísticas';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Da anterior configuración só se salvaron os prefixos das miniaturas e o correo do administrador web';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Só o administrador pode efectuar actualizacións: inicia sesión no formulario de abaixo.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'En <i>%s</i>, antes de <b>?></b>, insira:';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Por precaución, os seguintes engadidos foron desactivados. Tes que comprobar se teñen actualización antes de reactivalos:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Por precaución, os seguintes temas foron desactivados. Tes que comprobar se teñen actualización antes de reactivalos:';
$lang['All sub-albums of private albums become private'] = 'Tódolos sub-álbums de álbums privados tórnanse privados';
?>
